Fast dataset discovery and archive helpers for thesa and other Rust tools.
Made by Trevor Knott for Knott Dynamics.
DataForge normalizes dataset targets, queries public dataset catalogs, and archives dataset files with bounded concurrent downloads. The first-class provider is Hugging Face Datasets; Zenodo is included for DOI/record-backed research datasets.
assert_eq!(
dataforge::parse_dataset_target_for_provider(
"https://huggingface.co/datasets/squad",
dataforge::DatasetProvider::Hf,
)
.unwrap(),
dataforge::DatasetTarget::Dataset("squad".to_string())
);
assert_eq!(
dataforge::DatasetProvider::from_slug("hugging-face"),
Some(dataforge::DatasetProvider::Hf)
);Structs
- Archive
Failure - Failed dataset or file archive entry.
- Archive
Options - Options controlling archive writes.
- Archive
Summary - Summary returned after an archive run.
- Archived
File - One archived or skipped file.
- Data
Forge - Blocking dataset discovery and archive client.
- Dataset
Details - Full dataset metadata plus files to archive.
- Dataset
File - One downloadable file in a dataset archive.
- Dataset
Summary - Lightweight dataset metadata returned by discovery calls.
Enums
- Data
Forge Error - Errors returned by DataForge.
- Dataset
Provider - Supported dataset providers.
- Dataset
Target - Normalized dataset target requested by a user or CLI.
Functions
- parse_
dataset_ target - Parse a Hugging Face-style dataset target.
- parse_
dataset_ target_ for_ provider - Parse a dataset target using provider-specific rules.
Type Aliases
- Result
- Result type used by DataForge APIs.