pub struct ArchiveSummary {
pub discovered: usize,
pub selected: usize,
pub archived: usize,
pub skipped: usize,
pub files_archived: usize,
pub bytes_written: u64,
pub files: Vec<ArchivedFile>,
pub failed: Vec<ArchiveFailure>,
}Expand description
Summary returned after an archive run.
Fields
discovered: usizeNumber of datasets discovered before filtering and archiving.
selected: usizeNumber of datasets selected after filter application.
archived: usizeNumber of dataset directories completed without file failures.
skipped: usizeNumber of dataset directories skipped because they already existed.
files_archived: usizeNumber of files written.
bytes_written: u64Bytes written during this run.
files: Vec<ArchivedFile>Per-file successful writes or skips.
failed: Vec<ArchiveFailure>Dataset or file failures.
Implementations
Sourceimpl ArchiveSummary
impl ArchiveSummary
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Return true when no archive failures occurred.
Sourcepub fn failed_dataset_count(&self) -> usize
pub fn failed_dataset_count(&self) -> usize
Number of unique datasets with at least one failure.